# django-asyncmailer [![Build Status](https://travis-ci.org/andyfangdz/django-asyncmailer.svg?branch=master)](https://travis-ci.org/andyfangdz/django-asyncmailer)
Async email solution w/ multiple SMTP credentials, load-balancing and blacklist.
